==> gqylpy_datastruct-1.0-py3-none-any.whl: gqylpy_datastruct/__init__.py <==
"""
─────────────────────────────────────────────────────────────────────────────────────────────────────
─██████████████─██████████████───████████──████████─██████─────────██████████████─████████──████████─
─██░░░░░░░░░░██─██░░░░░░░░░░██───██░░░░██──██░░░░██─██░░██─────────██░░░░░░░░░░██─██░░░░██──██░░░░██─
─██░░██████████─██░░██████░░██───████░░██──██░░████─██░░██─────────██░░██████░░██─████░░██──██░░████─
─██░░██─────────██░░██──██░░██─────██░░░░██░░░░██───██░░██─────────██░░██──██░░██───██░░░░██░░░░██───
─██░░██─────────██░░██──██░░██─────████░░░░░░████───██░░██─────────██░░██████░░██───████░░░░░░████───
─██░░██──██████─██░░██──██░░██───────████░░████─────██░░██─────────██░░░░░░░░░░██─────████░░████─────
─██░░██──██░░██─██░░██──██░░██─────────██░░██───────██░░██─────────██░░██████████───────██░░██───────
─██░░██──██░░██─██░░██──██░░██─────────██░░██───────██░░██─────────██░░██───────────────██░░██───────
─██░░██████░░██─██░░██████░░████───────██░░██───────██░░██████████─██░░██───────────────██░░██───────
─██░░░░░░░░░░██─██░░░░░░░░░░░░██───────██░░██───────██░░░░░░░░░░██─██░░██───────────────██░░██───────
─██████████████─████████████████───────██████───────██████████████─██████───────────────██████───────
─────────────────────────────────────────────────────────────────────────────────────────────────────

Copyright (c) 2022 GQYLPY <http://gqylpy.com>. All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
__version__ = 1, 0
__author__ = '竹永康 <gqylpy@outlook.com>'
__source__ = 'https://github.com/gqylpy/gqylpy-datastruct'


class DataStruct:

    def __init__(self, blueprint: dict):
        """
        @param blueprint:
            Receive a data blueprint.
            See the documentation at https://github.com/gqylpy/gqylpy-datastruct
            We provide an example in https://github.com/gqylpy/gqylpy-datastruct/blob/master/test.py
        """
        verify_and_upgrade(blueprint)
        self.blueprint = blueprint

    def verify(self, data: dict, *, eraise: bool = False) -> 'Union[dict, NoReturn]':
        """
        @param data:   Data to be verified.
        @param eraise: If true, an exception will be thrown if the verification fails.
        @return:       An error message, if the verification fails and parameter "eraise" is false.
        """
        err: Union[dict, NoneType] = verify(data, self.blueprint)

        if err and eraise:
            raise e[err.pop('title')](err)

        return err


class ______歌______琪______怡______玲______萍______云______:
    import sys

    __import__(f'{__name__}.{__name__[0]} {__name__[7:]}')
    gpack = sys.modules[__name__]
    gcode = globals()[f'{__name__[0]} {__name__[7:]}']

    for gname in globals():
        if gname[0] != '_' and hasattr(gcode, gname):
            gfunc = getattr(gcode, gname)
            gfunc.__module__ = __package__
            setattr(gpack, gname, gfunc)


from typing import Union, NoReturn

try:
    from types import NoneType
except ImportError:
    NoneType = type(None)

==> gqylpy_datastruct-1.0.2-py3-none-any.whl: gqylpy_datastruct/__init__.py <==
"""
─────────────────────────────────────────────────────────────────────────────────────────────────────
─██████████████─██████████████───████████──████████─██████─────────██████████████─████████──████████─
─██░░░░░░░░░░██─██░░░░░░░░░░██───██░░░░██──██░░░░██─██░░██─────────██░░░░░░░░░░██─██░░░░██──██░░░░██─
─██░░██████████─██░░██████░░██───████░░██──██░░████─██░░██─────────██░░██████░░██─████░░██──██░░████─
─██░░██─────────██░░██──██░░██─────██░░░░██░░░░██───██░░██─────────██░░██──██░░██───██░░░░██░░░░██───
─██░░██─────────██░░██──██░░██─────████░░░░░░████───██░░██─────────██░░██████░░██───████░░░░░░████───
─██░░██──██████─██░░██──██░░██───────████░░████─────██░░██─────────██░░░░░░░░░░██─────████░░████─────
─██░░██──██░░██─██░░██──██░░██─────────██░░██───────██░░██─────────██░░██████████───────██░░██───────
─██░░██──██░░██─██░░██──██░░██─────────██░░██───────██░░██─────────██░░██───────────────██░░██───────
─██░░██████░░██─██░░██████░░████───────██░░██───────██░░██████████─██░░██───────────────██░░██───────
─██░░░░░░░░░░██─██░░░░░░░░░░░░██───────██░░██───────██░░░░░░░░░░██─██░░██───────────────██░░██───────
─██████████████─████████████████───────██████───────██████████████─██████───────────────██████───────
─────────────────────────────────────────────────────────────────────────────────────────────────────

Copyright (c) 2022 GQYLPY <http://gqylpy.com>. All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
__version__ = 1, 0, 2
__author__ = '竹永康 <gqylpy@outlook.com>'
__source__ = 'https://github.com/gqylpy/gqylpy-datastruct'


class DataStruct:

    def __init__(self, blueprint: dict):
        """
        @param blueprint:
            Receive a data blueprint.
            See the documentation at https://github.com/gqylpy/gqylpy-datastruct
            We provide an example in https://github.com/gqylpy/gqylpy-datastruct/blob/master/test.py
        """
        verify_and_upgrade(blueprint)
        self.blueprint = blueprint

    def verify(self, data: dict, *, eraise: bool = False) -> 'Union[dict, None]':
        """
        @param data:   Data to be verified.
        @param eraise: If true, an exception will be thrown if the verification fails.
        @return:       An error message, if the verification fails and parameter "eraise" is false.
        """
        err: Union[dict, None] = verify(data, self.blueprint)

        if err and eraise:
            raise type(err.pop('title'), (Exception,), {})(err)

        return err


class _xe6_xad_x8c_xe7_x90_xaa_xe6_x80_xa1_xe7_x8e_xb2_xe8_x90_x8d_xe4_xba_x91:
    import sys

    __import__(f'{__name__}.{__name__[0]} {__name__[7:]}')
    gpack = sys.modules[__name__]
    gcode = globals()[f'{__name__[0]} {__name__[7:]}']

    for gname in globals():
        if gname[0] != '_' and hasattr(gcode, gname):
            gfunc = getattr(gcode, gname)
            gfunc.__module__ = __package__
            setattr(gpack, gname, gfunc)


from typing import Union
